//author: Rebecca Bielamowicz and Jessica Su
//program: 2_clean_data.do
//project: do file that creates clean dataset with time-varying and invariant covariates for each AH respondent

cap log close
set more off

* Define path globals
global raw "D:/ahd/researchers/jhs/jhs_projects/raw_data"
global data "D:/ahd/researchers/jhs/jhs_projects/data"
global log "D:/ahd/researchers/jhs/jhs_projects/log_files/sexism replication logs"
global sysdate=c(current_date)

cd "$log"
log using "2_clean_data_$sysdate.log", replace

**************************************************************************************
**************************************************************************************
********************************* KHSES - KATHIE *************************************
********************************* KHSES - KATHIE *************************************
**************************************************************************************
**************************************************************************************

* Note: see the "Wave I Background Vars documentation.docx" document in the harris_SOCI_826 folder on the terminal server for the detailed codes for these variables.

use "$raw/khses", clear

//Age at Wave 1
destring w1ageint, gen(age1) force 					// N = 1 person whose age was NA at W1

//Age at Wave 4
destring w4ageint, gen(age4) force 					// N = 5,044 respondents with missing values (those not interviewed at W4)

//Race at Wave 1. 
destring raceth, gen(race1) force						// N = 58 respondents missing race; "NA" in raceth.

lab def race1_lbl 1"NH White" 2"NH Black" 3"NH Asian" 4"NH Other/Native Amer." 5"Hispanic"
lab val race1 race1_lbl
lab var race1 "Wave 1 Race"

//Highest level of parental education at Wave 1.
gen paredu1 = w1predu

lab def paredu1_lbl 1"No sch/<=8th grade" 2">=8th/vocational" 3"GED" 4"HS" 5"Vocational/Not grad college" 6"College grad" 7"Prof. training post college" 8"Missing"
lab val paredu1 paredu1_lbl
lab var paredu1 "W1 highest parental edu"

recode paredu1 (1/2=1) (3/4=2) (5=3) (6/7=4) (8=.)
lab def paredu 1 "1 lths" 2 "2 hs/ged" 3 "3 some coll/tech" 4 "4 BA+", replace
lab val paredu1 paredu

//Sex at Wave 1. Note: this var was corrected across 4 waves of data (why the 1234).
gen sex1 = w1234sex

//Keep only newly created vars + aid
keep aid race1 age1 age4 paredu1 sex1

//Save in data (not raw_data) folder. Use same naming convention as original file, but with _edit.
save "$data/khses_edit", replace

**************************************************************************************
**************************************************************************************
********************************* Wave 5 In-Home *************************************
********************************* Wave 5 In-Home *************************************
**************************************************************************************
**************************************************************************************

* Start by using the constructed age5 file, which has the correct version of respondents' age (Before, I was manually calculated their ages, but found the constructed file on the terminal server. My calculations, based on their birthdays and interview day/year, were slightly off - about 700/12,300 were incorrect. 
use "$raw/agew5", clear
destring aid, replace
keep aid age
tempfile age5
save "`age5'", replace

use "$raw/wave5", clear

destring aid, replace

merge 1:1 aid using "`age5'"
drop _merge
rename age age5

//Indicator for whether they were interviewed at this wave
gen wave5 = 1

//Number of live births
gen livebirths5=h5se22
replace livebirths5=0 if h5se22==997
replace livebirths5=. if h5se22==998
lab var livebirths5 "W5 # of live births"

//Age at first birth. Use h5pg10y1-6
gen kid1y = h5pg10y1
gen kid2y = h5pg10y2
gen kid3y = h5pg10y3
gen kid4y = h5pg10y4
gen kid5y = h5pg10y5
gen kid6y = h5pg10y6

foreach v of varlist kid*y {
	recode `v' 99997 = .
}

//Age at First Birth. Use the pregnancy history file (sect16.pdf = codebook). Use only vars related to kid1. 
gen testage = iyear5-h5od1y								// see how your age measure compares
gen testage_flag = 1 if age5!=testage
sort testage_flag
gen diffage = (testage-age5)
replace testage = testage-1 if diffage==1 & imonth5<=h5od1m		// respondents who have not yet had their birthdays that year

gen age5_flag = 1 if age5!=testage						// respondents who still have discrepancies between constructed age and my calculations of age, even with correcting for respondents who have not yet had their birthdays (N = 135). So, conclude that it is ok to use R's birthday month and year to calculate child age, while flagging these 135 cases. 

order i*5 h5od1m h5od1y age5 testage* diffage age5_flag

gen child1by = h5pg10y1
recode child1by 99997 = .
gen child1bm = h5pg10m1
recode child1bm 997 = .
lab var child1by "First child birth year W5"

gen b1birthdate5=ym(child1by, child1bm)
format b1birthdate5 %tm
lab var b1birthdate5 "First child birthdate W5"


gen disty1 = iyear5-child1by
gen distm1 = imonth5-child1bm

gen agebirth1 = (age5-disty1)
replace agebirth1 = agebirth1-1 if child1bm<h5od1m		// child birth month is less than parent birth month, parent has not yet turned that age for that year, so subtract 1.

order i*5 h5od1m h5od1y age5 testage* diffage age5_flag child1by child1bm disty distm agebirth1 b1birthdate5

lab var agebirth1 "Age at first birth, measured W5"

//Keep only newly created vars + aid
keep aid age5 wave5 agebirth1 child1by child1bm iyear5 livebirths5 b1birthdate5 

//Save in data (not raw_data) folder. Use same naming convention as original file, but with _edit.
save "$data/wave5_edit", replace

**************************************************************************************
**************************************************************************************
********************************* Wave 4 In-Home *************************************
********************************* Wave 4 In-Home *************************************
**************************************************************************************
**************************************************************************************
use "$raw/wave4", clear

destring aid, replace

//Indicator for whether they were interviewed at this wave
gen wave4 = 1

lab var wave4 "R interviewed at W4"

gen rbirthyr4=h4od1y
gen rbirthmo4=h4od1m
gen rbirthdate4=ym(rbirthyr4, rbirthmo4)
format rbirthdate4 %tm
lab var rbirthdate4 "R birthdate W4"

//live births
gen livebirth4=h4tr10
//Code as missing if refused or don't know number of live births
replace livebirth4=. if livebirth4>=96
//if respondent was never pregnant coding as 0 live births
replace livebirth4=0 if h4tr9==0 
lab var livebirth4 "Num live births W4"

//wave 4 interview date
gen w4intdate=ym(iyear4,imonth4) 
format w4intdate %tm
lab var w4intdate "W4 interview date"

//Keep only newly created vars + aid
keep aid wave4 livebirth4 iyear4 rbirthdate4 w4intdate

//Save
cd "$data"
save wave4_edit, replace

************************************************************************************************
************************************************************************************************
*********************************** Wave 4 Pregnancy Table *************************************
*********************************** Wave 4 Pregnancy Table *************************************
************************************************************************************************
************************************************************************************************

use "$raw/sect18", clear

destring aid, replace

sort aid h4pg3y h4pg3m 

by aid (h4pg3y h4pg3m): gen id = _n					// creates pregnancy # identifier based on month and year of birth (chronological order, from earliest to most recent birth). Captures twins. Issue with prgno in dataset is that it is per partner, so its values do not capture 1st, 2nd, 3rd birth for respondents who have multiple pregnancy partners. 

keep aid id h4pg8 h4pg1 h4pg3m h4pg3y h4pg9 h4pg10 h4pg11

rename h4pg1 outcome
rename h4pg3m monthend
rename h4pg3y yearend

keep aid outcome monthend yearend id
//Data is structured in long format, one record per pregnancy
//I am reshaping wide, one record per respondent
reshape wide outcome monthend yearend, i(aid) j(id)

//Identify first birth

gen firstbirthid=0
forval i=1/29 {
	replace firstbirthid=`i' if (outcome`i'==5 | outcome`i'==6) & firstbirthid==0       
}


//Assign values for pregnancy that resulted in first live birth
gen b1birthmo4=.
gen b1birthyr4=.

forval i=1/10 {
replace b1birthmo4=monthend`i' if firstbirthid==`i'
replace b1birthyr4=yearend`i' if firstbirthid==`i'
}

//Birthdate of first birth
replace b1birthmo4=. if b1birthmo4>12
lab var b1birthmo4 "Month of first birth"

replace b1birthyr4=. if b1birthyr4>2008
lab var b1birthyr4 "Year of first birth"

gen b1birthdate4=ym(b1birthyr4, b1birthmo4)
format b1birthdate4 %tm
lab var b1birthdate4 "First birth birthdate W4"

keep aid b1birthdate4 b1birthyr4 

save "$data/sect18_edit", replace


**************************************************************************************
**************************************************************************************
********************************* Wave 1 In-Home *************************************
********************************* Wave 1 In-Home *************************************
**************************************************************************************
**************************************************************************************
use "$raw/allwave1", clear

destring aid scid sscid, replace
replace scid=. if scid==999
replace sscid=. if sscid==999
//Indicator for whether they were interviewed at this wave
gen wave1 = 1

//wave 1 interview date
replace iyear=1900+iyear
gen w1intdate=ym(iyear,imonth) 
format w1intdate %tm
lab var w1intdate "W1 interview date"

//respondent's birth date
gen rbirthmo1=h1gi1m
replace rbirthmo1=. if rbirthmo1==96

gen rbirthyr1=h1gi1y
replace rbirthyr1=. if rbirthyr1==96
replace rbirthyr1=1900+rbirthyr1

gen rbirthdate1=ym(rbirthyr1, rbirthmo1)
format rbirthdate1 %tm
lab var rbirthdate1 "R birthdate W1"

//calculate respondent's age1
//interview date
gen w1age=(w1intdate-rbirthdate1)/12

gen female=.
replace female=1 if bio_sex==2
replace female=0 if bio_sex==1

gen borninus=.
replace borninus=1 if h1gi11==1 | h1gi11==7
replace borninus=0 if h1gi11==0 
lab var borninus "R born in the US"
lab def yesno 0 "0 no" 1 "1 yes", replace
lab val borninus yesno

//Social norms about sex (respect and embarassment)
//h1mo2= if sex lose partner respect
//h1mo3= if sex would feel guilty
//h1mo4= if sex upset mother
//h1mo9= if pregnant embarass family
//h1mo10= if pregnant embarass self 

//response options are:
//1=strongly agree
//2=agree
//3=neither agree nor disagree
//4=disagree
//5=strongly disagree
//6=refused
//7=legitimate skip (if married or respondent<=15)
//8=don't know
//9=not applicable

//higher values indicate more respect, less guilt/embarassment

foreach var of varlist h1mo2 h1mo3 h1mo4 h1mo9 h1mo10 {
  replace `var' =. if `var'>=6
  }
  
rename h1mo2 sexpartneresp
rename h1mo3 sexnoguilt
rename h1mo4 sexnotupsetmom
rename h1mo9 sexnoembarfam
rename h1mo10 sexnoembarresp

global sexposnorms sexpartneresp sexnoguilt sexnotupsetmom sexnoembarfam sexnoembarresp
alpha $sexposnorms, item detail
egen sexposnorms=rmean($sexposnorms)
egen sexposnorms_miss=rmiss($sexposnorms)
replace sexposnorms=. if sexposnorms_miss>4
lab var sexposnorms "Positive social norms about sex (respect/embarassment)"

//any romantic relationship in past 18 months
//H1RR1
gen anyrel=.
replace anyrel=1 if h1rr1==1
replace anyrel=0 if h1rr1==0
lab var anyrel "Any relationship past 18 months"

//relationship 1
//date of relationship 1
replace h1ri1m_1=. if h1ri1m_1>12
replace h1ri1m_1=. if h1ri1m_1==0

replace h1ri1y_1=. if h1ri1y_1>95
replace h1ri1y_1=. if h1ri1y_1==0
replace h1ri1y_1=1900+h1ri1y_1

replace h1ri2_1=. if h1ri2_1>95
replace h1ri2_1=1900+h1ri2_1

//If respondents didn't know exact date they were asked the year
//I am coding them as starting in month 6 to get an approximate reldate
replace h1ri1y_1=h1ri2_1 if h1ri1y_1==. & h1ri2_1!=.
replace h1ri1m_1=6 if h1ri1m_1==. & h1ri2_1!=.

gen r1reldate=ym(h1ri1y_1, h1ri1m_1)
format r1reldate %tm
lab var r1reldate "First relationship start date"

//age of romantic partner
//H1RI3_1
//H1RI4_1

replace h1ri3_1=. if h1ri3_1>53
replace h1ri4_1=. if h1ri4_1>24
replace h1ri3_1=h1ri4_1 if h1ri3_1==. & h1ri4_1!=.

gen partner1age=h1ri3_1

//sex of romantic partner
//1=male, 2=female
//H1RI20_1
gen partner1male=.
replace partner1male=1 if h1ri20_1==1
replace partner1male=0 if h1ri20_1==2

//The next questions are about romantic relationships. Please imagine your ideal romantic
//relationship in the next year. Go through this deck of cards and give me any that
//describe things that would NOT happen in this perfect relationship.

/*If the respondent refused to answer this question ("6"), then all these variables are coded "6" and he or
she was not asked the subsequent question, that is, they could not order
any of the cards, H1ID2_1 through H1ID2_17. These variables are all !
(missing). If, however, the respondent didn't know ("8") which activities
would take place in his or her ideal relationship or thought the question
was not applicable ("9"), he or she could order all the cards in the
subsequent question H1ID2_1 through H1ID2_17.
*/
gen idealrel_sex=.
replace idealrel_sex=1 if h1id1o==1
replace idealrel_sex=0 if h1id1o==2 
lab var idealrel_sex "Ideal relationship includes sex"

by scid, sort: tab idealrel_sex female, col missing

/*
//Regardless of whether you have done these things or not, how would your mother
feel about each of the following things? (If MOM  "biological mother," add: I mean, the
mother you live with.)
*/
//How would she feel about your having sex at this time in your life?
gen momapprovesex=h1pa1 
replace momapprovesex=. if h1pa1>5 
lab def momapprove 1 "1 strongly disapprove" 2 "2 disapprove" 3 "3 neither dis/approve" 4 "4 approve" 5 "5 strongly approve", replace
lab val momapprovesex momapprove
lab var momapprovesex "Would mom approve of R having sex"

//During the past week, how many times did you do work around the house, such as cleaning, cooking, laundry, yardwork, or caring for a pet?
tab h1da1
replace h1da1=. if h1da1>3
gen housework=h1da1
tab housework female, col

/*
Do you agree or disagree that the sacred scriptures of
your religion are the word of God and are completely
without any mistakes?
*/
//coded as "no" if they were skipped out of question because they don't report a religious denomination (h1re2==7)
gen scripture=.
replace scripture=1 if h1re2==1
replace scripture=0 if h1re2==2 | h1re2==3 | h1re2==7
lab var scripture "scriptures are word of god w1"

//hourly wage during the school year
gen workhrs_school=h1ee4
replace workhrs_school=. if h1ee4>=996

gen earnings_school=h1ee5
replace earnings_school=. if h1ee5>=996

gen hrwage_school=earnings_school/workhrs_school
replace hrwage_school=. if hrwage_school==0
lab var hrwage_school "Avg weekly wage during school year"

	
//Keep only newly created vars + aid
keep aid scid sscid wave1 w1intdate iyear rbirthdate1 rbirthyr1 rbirthmo1 borninus ///
			sexposnorms idealrel_sex momapprovesex housework hrwage_school anyrel r1reldate partner1age partner1male scripture  

//Save in data (not raw_data) folder. Use same naming convention as original file, but with _edit.
save "$data/allwave1_edit", replace

//note: school-level averages are created in 4_clean_merged

**************************************************************************************
**************************************************************************************
********************************* Wave 1 Constructed Family Structure*****************
**************************************************************************************
**************************************************************************************
use "$raw/famst", clear

destring aid, replace

gen w1famst=famst5
recode w1famst (4=3) (5=4)
lab var w1famst "w1 family structure"
lab def w1famst 1 "1 two bio parents" 2 "2 stepfamily" 3 "3 single parent" 4 "4 other", replace
lab val w1famst w1famst

keep aid w1famst
save "$data/famst_edit", replace

**************************************************************************************
**************************************************************************************
********************************* Contextual Files ***********************************
**************************************************************************************
**************************************************************************************
use "$raw/context1", clear
destring aid, replace

//indicator of geocode match
recode match (0=0) (1=1) (2=1) (3=1) (4=1) (5=1)
lab def match 0 "0 no match" 1 "1 GPS, address, zip match", replace
lab val match match

****************************************************************
//INSTITUTIONAL SEXISM
****************************************************************
//1. the ratio of men's to women's labor force participation- wave 1
//proportion males age 16+ in civilian labor force cst90732
//proportion females age 16+ in civilian labor force cst90715

gen cacw1mflabor=cst90732/cst90715
lab var cacw1mflabor "ratio m/f labor force part w1 (county)"

//2. the county-level proportion of voters for the republican presidential candidate
sum ccu92a28 

//3. the county level proportion of conservative religious adherents (all religions combined)
sum ccm90a15

//4. Public funding for abortion captured whether the state provided funding for abortion in limited circumstances (e.g. rape, incest, or life endangerment; yes=1) or in all or most circumstances (referent= 0). 
gen w1limabortfund=.
replace w1limabortfund=1 if sna95a67==1 | sna95a67==2 | sna95a67==3
replace w1limabortfund=0 if sna95a67==4

tab sna95a67 w1limabortfund , missing

lab var w1limabortfund "Limited public funding of abortion"
lab def abortfund 1 "1 limited (rape, incest, life endangerment)" 0 "0 all or most circumstances", replace
lab val w1limabortfund abortfund

//5. Mandatory waiting periods and informed consent for abortion captured whether there was a state-level requirement that pregnant people receive lectures and state-prepared materials on fetal development, prenatal care and adoption, and mandatory waiting period after such information is received. 
gen w1informconsent=.
replace w1informconsent=0 if sna95a65==1
replace w1informconsent=0 if sna95a65==2 | sna95a65==3
replace w1informconsent=1 if sna95a65==4

lab var w1informconsent "Mandatory waiting periods and informed consent"
lab def informconsent 0 "0 no informed consent law or no waiting enforced" 1 "1 informed consent law, mandatory waiting", replace
lab val w1informconsent informconsent


//6. Parental consent for abortion was measured at the state-level and captures whether states have no parental consent laws (0), unenforced consent laws (1), or enforced consent laws (2). 
gen w1parconsent=.
replace w1parconsent=0 if sna95a66==1
replace w1parconsent=1 if sna95a66==2
replace w1parconsent=2 if sna95a66==3

lab var w1parconsent "Law to prevent abortions by minors without parental consent"
lab def parconsent 0 "0 no parental consent" 1 "1 unenforced consent law" 2 "2 enforced consent law", replace
lab val w1parconsent parconsent

//7. whether the respondent's county had an abortion provider (0=at least one abortion provider; 1=no provider). 
gen w1noabprov=.
replace w1noabprov=1 if cag92958==0
replace w1noabprov=0 if cag92958==1

lab var w1noabprov "No abortion provider in R's county"
lab def noabprov 0 "0 at least 1 abortion provider" 1 "1 no provider", replace
lab val w1noabprov noabprov

****************************************************************
//County-level covariates
****************************************************************
//County racial composition
gen countyblack=cst90007
gen countyhispanic=cst90011

//W1 poverty status
sum cst90598
xtile w1cpovquint = cst90598, nq(5)

keep aid match cacw1mflabor ccu92a28 ccm90a15 w1limabortfund w1informconsent w1parconsent w1noabprov countyblack countyhispanic w1cpovquint
save "$data/context1_edit", replace

**************************************************************************************
**************************************************************************************
********************************* Weights ********************************************
**************************************************************************************
**************************************************************************************

use "$raw/Homewt1", clear
destring aid, replace
save "$data/Homewt1_edit", replace

use "$raw/w1homewc", clear
destring aid, replace
save "$data/w1homewc_edit", replace

//grouping variables to identify state
/*
These identifiers are based on Census block group FIPS codes. To group respondents at courser levels of Census geography, extract the first 11 characters for tracts, the first five characters for counties, and the first two characters for state. It is important to note that even though these identifiers are numeric in nature, they need to remain as text or string variables as some of the codes begin with 0, which will be lost if converted to numeric.
*/
use "$raw/w1_5grp", clear
destring aid, replace

gen w1stringstate=substr(w5group1,1,2)
destring w1stringstate, gen(w1state)
replace w1state=. if w5group1=="999999999999"
lab var w1state "Wave 1 state"

keep aid w1state 
save "$data/w1_5grp_edit", replace


log close
