//author: Jessica Su
//program: 4_clean_merged.do
//project: do file that cleans the merged AH data
//Make any variables that couldn't be done when files were separate 
//(i.e., two variables that you need to create another are in separate files).

cap log close
set more off

* Define path globals
global data "D:/ahd/researchers/jhs/jhs_projects/data"
global log "D:/ahd/researchers/jhs/jhs_projects/log_files/sexism replication logs"
global sysdate=c(current_date)

cd "$log"
log using "4_clean_merged_$sysdate.log", replace

use "$data/jhs_data", clear

**************************************************************************************
//////////////////
//EARLY FIRST BIRTH
//////////////////
//Calculate age at first birth based on W4 reports
gen agebirth1_4=round((b1birthdate4-rbirthdate1)/12)

//calculate age at first birth based on W5 reports
gen agebirth1_5=round((b1birthdate5-rbirthdate1)/12)
replace agebirth1_5=. if agebirth1_5==0

gen agebirth1_45=agebirth1_4
//how many values are from wave 4?
tab agebirth1_45
//n=7657
tab agebirth1_45 if agebirth1_45<22
//n=2990 early births reported at wave 4

replace agebirth1_45=agebirth1_5 if agebirth1_4==. & agebirth1_5!=.
//how many values are from wave 5?
tab agebirth1_45
//Total n for this variable is no 11022, which means that 11022-7657=3365 are from wave 5
//3365/11022=.305; 31% of reports are from wave 5

tab agebirth1_45 if agebirth1_45<22
//n=3290 early births total combining wave 4 and wave 5
//di 3290-2990 =300
//di 300/3290
//91% of early births reported at wave 4, 9% of early births reported at wave 5

////////////////////////////////////////////////////////////////////////////////////////////
//Control variables
gen female=.
replace female=1 if sex1==2
replace female=0 if sex1==1
lab var female "R is female"

gen racecat1=.
replace racecat1=1 if race1==1
replace racecat1=2 if race1==2
replace racecat1=3 if race1==5
replace racecat1=4 if race1==3 | race1==4
lab def racecat 1 "1 NH White" 2 "2 NH Black" 3 "3 Hispanic" 4 "4 NH Other", replace
lab val racecat1 racecat
lab var racecat1 "W1 Race"

gen pareducat1=.
lab var pareducat1 "W1 highest parental edu"
replace pareducat1=1 if paredu1==1 | paredu1==2 //lths
replace pareducat1=2 if paredu1==3 | paredu1==4 //HS/GED
replace pareducat1=3 if paredu1==5 //vocational
replace pareducat1=4 if paredu1==6 | paredu1==7 //college+
lab def pareducat 1 "1 lths" 2 "2 HS/GED" 3 "3 Vocational" 4 "4 College+", replace
lab val pareducat1 pareducat

//age difference for relationship
//calculate R age at time of relationship
gen rel1age=(r1reldate-rbirthdate1)/12
replace rel1age=. if rel1age<5

gen r1agediff=rel1age-partner1age
order r1reldate rbirthdate1 rel1age r1agediff female partner1male

//average age difference if R is female and partner is male
sum r1agediff if female==1 & partner1male==1
//average age difference if R is male and partner is female
sum r1agediff if female==0 & partner1male==0

//summarize this so that positive value always indicates male is older than female 
//negative value means that female is older than male
//first calculate age difference for male respondents with female partners (male age-female age)
gen r1malefemaleagediff=rel1age-partner1age if female==0 & partner1male==0
//next calculate age difference for female respondents with male partners (male age-female age)
replace r1malefemaleagediff=partner1age-rel1age if female==1 & partner1male==1
lab var r1malefemaleagediff "relationship 1 male age-female age"

sort scid
egen nagediff = total(r1malefemaleagediff!=.), by(scid)
lab var nagediff "Number of rel age diff within school"

//r1malefemaleagediff nagediff 
bysort scid: egen avgrelagediff=mean(r1malefemaleagediff)
lab var avgrelagediff "Average rel1 male-female age diff by school"

//calculate age diff ratio. This will take into account the significance of larger age gap at younger ages.
//for example, difference between 18 and 16 is 2 years, difference between 28 and 26 is 2 years
//however, ratio of 18/16=1.125, ratio of 28/16 is 1.076
gen r1mfage=.
replace r1mfage=rel1age/partner1age if female==0 & partner1male==0
replace r1mfage=partner1age/rel1age if female==1 & partner1male==1


/////////////////////////////////////////////////////////////////////////////////////////////////
//school-level averages 
codebook scid
//we have n=145 schools

order scid aid female sexposnorms idealrel_sex momapprovesex housework hrwage_school 
sort scid female

global mfratio sexposnorms idealrel_sex  momapprovesex housework hrwage_school 
sum $mfratio
sum $mfratio if female==1
sum $mfratio if female==0

//note that we have 14,951 respondents age>15 at wave 1
foreach var in $mfratio {
	egen n`var'_fem=total(`var'!=. & female==1), by(scid)
	egen n`var'_male=total(`var'!=. & female==0), by(scid)
	lab var n`var'_fem "Number of female R in school with valid `var'"
	lab var n`var'_male "Number of male R in school with valid `var'"
}

by scid: generate schoolobs = _N
replace schoolobs=. if scid==.
lab var schoolob "Number of observations per school"
by scid: generate schoolrid = _n
lab var schoolrid "Observation number within school"
order aid scid schoolobs schoolrid

//How many observations within school are >15? 
//note that we do have an age variable in the dataset, age1, but it is rounded.
//I need more detail because respondents who were even 1 day older than 15 were asked the questions.
gen w1age=(w1intdate-rbirthdate1)/12
bys scid: egen schoolobs15=total(w1age>15 & w1age!=.)

list scid schoolobs schoolobs15 nsexposnorms* if schoolrid==1
list scid schoolobs schoolobs15 nidealrel_sex* nmomapprovesex* nhousework* nhrwage_school* if schoolrid==1


//Create school averages
foreach var of varlist sexposnorms idealrel_sex momapprovesex housework hrwage_school {
	gen `var'_f=.
	gen `var'_m=.
}

//list the schoolids that have enough male/female respondents to create within-school ratios 
#delim ;
global scidnum
1
2
3
6
7
8
9
10
12
13
14
15
17
18
19
20
21
22
23
24
25
26
27
28
29
33
34
35
39
40
41
42
44
46
47
49
50
52
53
54
55
56
57
58
59
60
62
64
65
66
67
68
70
71
72
73
74
75
76
77
78
79
80
81
84
85
86
87
88
90
91
92
93
94
106
109
114
117
118
119
120
121
122
123
126
127
139
141
142
144
147
149
150
152
153
154
155
157
158
160
162
164
166
167
168
170
171
172
174
176
177
185
186
187
193
203
259
269
270
271
371
;
#delim cr

//create unwtd school avgs
foreach var of varlist sexposnorms idealrel_sex momapprovesex housework hrwage_school {
	gen unwt`var'_f=.
	gen unwt`var'_m=.
}

sum unwt*_f unwt*_m

//averages for females within school
foreach var in sexposnorms idealrel_sex momapprovesex housework hrwage_school {
		foreach i of numlist $scidnum {
		di "`var' school `i'"
		qui summarize `var' if scid==`i' & female==1, detail
		replace unwt`var'_f=`r(mean)' if scid==`i'
}
}

//averages for males within school
foreach var in sexposnorms idealrel_sex momapprovesex housework hrwage_school  {
		foreach i of numlist $scidnum {
		di "`var' school `i'"
		qui summarize `var' if scid==`i' & female==0, detail
		replace unwt`var'_m=`r(mean)' if scid==`i'
}
}

//create m/f ratio to indicate male advantage
foreach var in sexposnorms idealrel_sex  momapprovesex  hrwage_school  {
	gen smfunwt_`var'=unwt`var'_m/unwt`var'_f
}

//create f/m ratio to indicate male advantage (for housework, females doing more indicates male advantage)
foreach var in housework  {
	gen sfmunwt_`var'=unwt`var'_f/unwt`var'_m
}

//create school averages for measures that do not need male/female ratio
bysort scid: egen avgscripture=mean(scripture)
lab var avgscripture "% scriptural inerrancy by school"

bysort scid: egen avgr1mfage=mean(r1mfage)
lab var avgr1mfage "avg male-female age diff relationship"


//look at ratios to see if there are outliers
/*

Gendered norms	
	smf_sexposnorms
	smfunwt_idealrel_sex
	smf_momapprovesex
	
Power in relationships	
	sfmunwt_housework
	smf_hrwage_school
	avgr1mfage
	
Traditional gender role ideology
	avgscripture
*/

sum unwtsexposnorms_m unwtsexposnorms_f smfunwt_sexposnorms 
sum unwtidealrel_sex_m unwtidealrel_sex_f smfunwt_idealrel_sex
sum unwtmomapprovesex_m unwtmomapprovesex_f smfunwt_momapprovesex 

sum unwthousework_f unwthousework_m sfmunwt_housework 
sum unwthrwage_school_m unwthrwage_school_f smfunwt_hrwage_school 

sum avgr1mfage avgscripture 

//looks like there are outliers for idealrelsex, hrwage, scripture
graph box smfunwt_idealrel_sex
graph box smfunwt_hrwage_school
graph box avgscripture

//Outliers may be concerning if they are due to schools with very small n's
//which schools have the highest values?
foreach var in idealrel_sex {
	sum smfunwt_`var', detail
	bysort scid: tab female if (smfunwt_`var'>`r(p99)' & smfunwt_`var'!=.), sum(`var')
}


foreach var in idealrel_sex  {
	sum smfunwt_`var', detail
	bysort scid: tab female if smfunwt_`var'<`r(p1)', sum(`var')
}

//Top code and bottom code 
foreach var in idealrel_sex {
	sum smfunwt_`var', detail
	replace smfunwt_`var'=`r(p99)' if smfunwt_`var'>`r(p99)' & smfunwt_`var'!=.
	replace smfunwt_`var'=`r(p1)' if smfunwt_`var'<`r(p1)'
}

//Address ratio that is missing due to 0 in denominator
list scid unwtidealrel_sex_m unwtidealrel_sex_f smfunwt_idealrel_sex if smfunwt_idealrel_sex==. & unwtidealrel_sex_m!=. & unwtidealrel_sex_f!=.

sum smfunwt_idealrel_sex, detail
replace smfunwt_idealrel_sex=`r(p99)' if smfunwt_idealrel_sex==. & unwtidealrel_sex_m!=. & unwtidealrel_sex_f==0

///////hourly wage
foreach var in hrwage_school {
	sum smfunwt_`var', detail
	bysort scid: tab female if (smfunwt_`var'>`r(p99)' & smfunwt_`var'!=.), sum(`var')
}


foreach var in hrwage_school  {
	sum smfunwt_`var', detail
	bysort scid: tab female if smfunwt_`var'<`r(p1)', sum(`var')
}

foreach var in hrwage_school {
	sum smfunwt_`var', detail
	replace smfunwt_`var'=`r(p99)' if smfunwt_`var'>`r(p99)' & smfunwt_`var'!=.
	replace smfunwt_`var'=`r(p1)' if smfunwt_`var'<`r(p1)'
}

sum smfunwt_hrwage_school, detail
list scid unwthrwage_school_m unwthrwage_school_f smfunwt_hrwage_school if smfunwt_hrwage_school==. & unwthrwage_school_m!=. & unwthrwage_school_f!=.


sum avgscripture, detail
tab avgscripture
list scid avgscripture if avgscripture==1
bysort scid: sum avgscripture if (avgscripture==1)

//label region variable values
lab def region 1 "1 West" 2 "2 Midwest" 3 "3 South" 4 "4 Northeast", replace
lab val region region

save "$data/jhs_merged_data", replace
