//author: Jessica Su
//program: 5_reshape_data.do
//project: do file that reshapes data into person-year format
cap log close
set more off

* Define path globals
global data "D:/ahd/researchers/jhs/jhs_projects/data"
global log "D:/ahd/researchers/jhs/jhs_projects/log_files/sexism replication logs"
global sysdate=c(current_date)

cd "$log"
log using "5_reshape_data_$sysdate.log", replace
use "$data/jhs_merged_data", clear

**************************************************************************************

//Look at distribution of age at first birth, weighted and unweighted
sum agebirth1_45, detail
sum agebirth1_45 [w=gswgt1], detail
//age 21 is the cutoff for the 25th percentile
//age 16 is the cutoff for the 1st percentile
		
//Need time-varying variables for first birth
//Observe from age 9 to 30
forval age=9/30 {
		gen year`age'=.
		gen firstbirth`age'=.
}

//Assign year for each age
forval age=9/30 {
	replace year`age'=rbirthyr1+(`age') if rbirthmo1>=1 & rbirthmo1<=6
	replace year`age'=rbirthyr1+(`age')+1 if rbirthmo1>=7 & rbirthmo1<=12
}

//Create categorical variable indicating first birth
//0=no first birth, 1=first birth that year, 2=first birth already happened
forval age=9/30 {
	replace firstbirth`age'=0 if (livebirth4!=. | livebirths5!=.) 
	replace firstbirth`age'=1 if agebirth1_45==`age' & agebirth1_45!=.
	replace firstbirth`age'=2 if agebirth1_45<`age' & agebirth1_45!=.
	replace firstbirth`age'=. if ((livebirth4>0 & livebirth4!=.) | (livebirths5>0 & livebirths5!=.))  & (agebirth1_45==.)
}
lab def firstbirth 0 "0 no birth" 1 "1 first birth" 2 "2 already gave birth", replace

forval age=9/30 {
	lab val firstbirth`age' firstbirth
}

//NEED TO SET FIRSTBIRTHAGE=. FOR THOSE WHO HAVE 0 CHILDREN BUT ARE NOT OBSERVED (right truncation)
//FOR EXAMPLE, IF OUR LAST REPORT WAS W4 AND THE RESPONDENT WAS age 28 years old, we should have missing data for firstbirth29 firstbirth30
forval age=24/30 {
	replace firstbirth`age'=. if (livebirth4==0 & livebirths5==.) & age4<`age' & age4!=.
}

keep year* firstbirth* wave* ///
female age1 ///
rbirthdate1 livebirths5 livebirth4 ///
cacw1mflabor ccu92a28 ccm90a15 w1limabortfund w1informconsent w1parconsent w1noabprov ///
smfunwt_sexposnorms  smfunwt_idealrel_sex  smfunwt_momapprovesex sfmunwt_housework smfunwt_hrwage_school avgr1mfage avgscripture ///
racecat1 borninus w1famst paredu1 w1cpovquint countyblack countyhispanic ///
w1state region ///
aid scid psuscid schwt1 w1_wc gswgt1 match ///
b1birthdate4 w1intdate

reshape long year firstbirth, i(aid) j(age)

lab var age "R age"
lab var year "Calendar Year"
lab var firstbirth "First birth status (tv)"

save "$data/jhs_context_long", replace
log close
exit