//author: Jessica Su
//program: 7_analytic_sample.do
//project: do file that analyzes the AH contextual data- long format

* Define path globals
global data "D:/ahd/researchers/jhs/jhs_projects/data"
global log "D:\ahd\researchers\jhs\jhs_projects\log_files\sexism replication logs"
global sysdate=c(current_date)

**************************************************************************************
cap log close
set more off
cd "$log"
log using "7_analyze_data_$sysdate.log", replace

use "$data/jhs_sexism_analysis", clear

xttab sample

//count the number of observations within aid by sample status
sort sample aid age 
by sample aid: generate nobs = _n 
tab sample nobs

//how many states do we have? 36
tab w1state if sample==1 & nobs==1
//how many schools do we have? 121
tab scid if sample==1 & nobs==1, sum(perfemale)

//multilevel model weights
svyset psuscid, weight(schwt1) strata(region) || aid, weight(w1_wc)

//define macros for variable groups 
global institutional c.cacw1mflabor c.ccu92a28 c.ccm90a15 i.w1limabortfund w1informconsent w1parconsent i.w1noabprov 
global institutional_nof cacw1mflabor ccu92a28 ccm90a15 w1limabortfund w1informconsent w1parconsent w1noabprov 

global interaction smfunwt_sexposnorms smfunwt_idealrel_sex smfunwt_momapprovesex sfmunwt_housework smfunwt_hrwage_school avgr1mfage avgscripture

global controls c.age c.year /// 
		c.perfemale i.w1cpovquint c.countyblack c.countyhispanic /// 
		i.racecat1 i.borninus i.w1famst i.paredu1 
	 
global controls_norace c.age c.year /// 
		c.perfemale i.w1cpovquint c.countyblack c.countyhispanic /// 
		i.borninus i.w1famst i.paredu1 
		
tab racecat1, gen(newrace)
tab w1famst, gen(newfam)
tab paredu1, gen(newparedu)
tab w1cpovquint, gen(newpov)
tab region, gen(newregion)	

global controls_nof age year /// 
		perfemale newpov1 newpov2 newpov3 newpov4 newpov5 countyblack countyhispanic /// 
		newrace1 newrace2 newrace3 newrace4 borninus newfam1 newfam2 newfam3 newfam4 newparedu1 newparedu2 newparedu3 newparedu4


//////////////////////////////////////////////////////
//descriptives by unique observations
//////////////////////////////////////////////////////

//aid*age uniquely identifies each observation
//however, some respondents may not be contributing at each age (some are left censored, some are right censored)
xttab age if sample==1
xttab sample 

gen widesamp=sample
replace widesamp=0 if nobs>1

//create variable for whether respondent gave birth before age 22 (variable is not time-varying)
by aid, sort: egen earlybirth=max(firstbirth) if sample==1
tab racecat1 earlybirth if widesamp==1, row

gen widesamp_nobirth=widesamp
replace widesamp_nobirth=0 if earlybirth==1

gen widesamp_early=widesamp
replace widesamp_early=0 if earlybirth==0


//Table 1. weighted sexism descriptives
svy, subpop(widesamp_early): mean $institutional institutional_sexism $interaction interaction_sexism_unwt
estat sd
svy, subpop(widesamp_nobirth): mean $institutional institutional_sexism $interaction interaction_sexism_unwt
estat sd

//weighted t-tests
foreach var in $institutional_nof institutional_sexism $interaction interaction_sexism_unwt {
	qui svy, subpop(widesamp): reg `var' earlybirth 
	if e(p)>.05 {
    di "`var' no statistical difference earlybirth vs nobirth"
       }
       if e(p)<.05 & e(p)>.01 {
       di "`var' is statistically different earlybirth vs nobirth at .05 - 1 star"
       }
       if e(p)<.01 & e(p)>.001 {
       di "`var' is statistically different earlybirth vs nobirth at .01 - 2 stars"
       }
       if e(p)<.001 {
       di "`var' is statistically different earlybirth vs nobirth at .001 - 3 stars"
       }
       }


//Appendix Table 1. covariate descriptives
//note that age and calendar year are time-varying measures, so the average we get from wide sample is at first observation

svy, subpop(widesamp_early): mean $controls 
estat sd

svy, subpop(widesamp_nobirth): mean $controls 
estat sd

//weighted t-tests
foreach var in $controls_nof {
	qui svy, subpop(widesamp): reg `var' earlybirth 
	if e(p)>.05 {
    di "`var' no statistical difference earlybirth vs nobirth"
       }
       if e(p)<.05 & e(p)>.01 {
       di "`var' is statistically different earlybirth vs nobirth at .05 - 1 star"
       }
       if e(p)<.01 & e(p)>.001 {
       di "`var' is statistically different earlybirth vs nobirth at .01 - 2 stars"
       }
       if e(p)<.001 {
       di "`var' is statistically different earlybirth vs nobirth at .001 - 3 stars"
       }
       }


//////////////////////////////////////////////////////
//REGRESSIONS
//////////////////////////////////////////////////////

********************************************************
//Table 2. Discrete-time logistic regression event history models with random effects predicting early childbearing (age 15-21)
svy, subpop(sample): melogit firstbirth c.institutional_sexism $controls c.age#c.age || psuscid:
	outreg2 using table2, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("Institutional") replace	
	
svy, subpop(sample): melogit firstbirth c.interaction_sexism_unwt $controls c.age#c.age || psuscid:
	outreg2 using table2, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("Interaction") append
	
svy, subpop(sample): melogit firstbirth c.institutional_sexism c.interaction_sexism_unwt $controls c.age#c.age || psuscid:
	outreg2 using table2, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("Institutional & Interaction") append	
test institutional_sexism interaction_sexism_unwt	

//Are institutional and interactional sexism non-additive?
svy, subpop(sample): melogit firstbirth c.institutional_sexism##c.interaction_sexism_unwt $controls c.age#c.age || psuscid:

********************************************************
//Appendix Table 2. sequential controls
//1. Baseline (age and age2)	
local append "replace"
foreach var in c.institutional_sexism c.interaction_sexism_unwt {

svy, subpop(sample): melogit firstbirth `var' c.age##c.age || psuscid:
	outreg2 using atable2, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("baseline") `append'

//2. Add confounders: calendar year to account for trends in teen childbearing and sexism; school and county level demographic characteristics (% female, racial composition, poverty) 
svy, subpop(sample): melogit firstbirth `var' c.age##c.age ///
						c.year c.perfemale i.w1cpovquint c.countyblack c.countyhispanic ///
		|| psuscid:
	outreg2 using atable2, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("confounders") append


//3. Add individual and family controls (family structure and parents' education)
svy, subpop(sample): melogit firstbirth `var' c.age##c.age ///
							c.year c.perfemale i.w1cpovquint c.countyblack c.countyhispanic  ///
							i.racecat1 i.borninus i.w1famst i.paredu1 ///
	|| psuscid:
	outreg2 using atable2, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("indiv/family") append	
	local append "append"
}	

//including both institutional and interactional
//1. Baseline (age and age2)	
svy, subpop(sample): melogit firstbirth c.institutional_sexism c.interaction_sexism_unwt c.age##c.age || psuscid:
	outreg2 using atable2, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("baseline") append
test institutional_sexism interaction_sexism_unwt	

//2. Add confounders: calendar year to account for trends in teen childbearing and sexism; school and county level demographic characteristics (% female, racial composition, poverty) 
svy, subpop(sample): melogit firstbirth c.institutional_sexism c.interaction_sexism_unwt c.age##c.age ///
						c.year c.perfemale i.w1cpovquint c.countyblack c.countyhispanic ///
		|| psuscid:
	outreg2 using atable2, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("confounders") append
test institutional_sexism interaction_sexism_unwt	


//3. Add individual and family controls (family structure and parents' education)
svy, subpop(sample): melogit firstbirth c.institutional_sexism c.interaction_sexism_unwt c.age##c.age ///
							c.year c.perfemale i.w1cpovquint c.countyblack c.countyhispanic  ///
							i.racecat1 i.borninus i.w1famst i.paredu1 ///
	|| psuscid:
	outreg2 using atable2, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("indiv/family") append	
test institutional_sexism interaction_sexism_unwt	

********************************************************
//Figure 4. 
//Predicted probability of first birth at different levels of interactional sexism 

margins, at (interaction_sexism_unwt=(-2(0.5)2)) atmeans predict(mu fixed)
marginsplot, recastci(rarea) ciopts(col(gs14))
graph save "Graph" "$log\Fig4.gph", replace


*************************
//Analysis by race
gen whitesample=sample
replace whitesample=0 if racecat1!=1 & racecat1!=.

gen blacksample=sample
replace blacksample=0 if racecat1!=2 & racecat1!=.

gen hispsample=sample
replace hispsample=0 if racecat1!=3 & racecat1!=.

xttab whitesample
xttab blacksample
xttab hispsample

tab w1state racecat if sample==1
tab w1state racecat if sample==1, nofreq col
tab w1state, sum(institutional_sexism)

********************************************************
//Table 3. sexism descriptives by race, wide sample
gen whitesampwide=widesamp
replace whitesampwide=0 if racecat1!=1 & racecat1!=.

gen blacksampwide=widesamp
replace blacksampwide=0 if racecat1!=2 & racecat1!=.

svy, subpop(whitesampwide): mean $institutional institutional_sexism $interaction interaction_sexism_unwt
estat sd

svy, subpop(blacksampwide): mean $institutional institutional_sexism $interaction interaction_sexism_unwt 
estat sd

//white vs black
gen whiteblack=.
replace whiteblack=1 if racecat1==1
replace whiteblack=0 if racecat1==2

gen widesamp_bw=widesamp
replace widesamp_bw=0 if racecat1!=1 & racecat1!=2 & racecat1!=.
tab racecat1 widesamp
tab racecat1 widesamp_bw
tab whiteblack widesamp_bw

gen samp_bw=sample
replace samp_bw=0 if racecat1!=1 & racecat1!=2 & racecat1!=.
tab racecat1 sample
tab racecat1 samp_bw
tab whiteblack samp_bw

gen blackwhite=.
replace blackwhite=0 if racecat1==1
replace blackwhite=1 if racecat1==2
lab def blackwhite 0 "0 White" 1 "1 Black", replace
lab val blackwhite blackwhite

//weighted t-tests
foreach var in $institutional_nof institutional_sexism $interaction interaction_sexism_unwt {
qui svy, subpop(widesamp_bw): reg `var' whiteblack 
if e(p)>.05 {
    di "`var' no statistical difference white vs black"
       }
       if e(p)<.05 & e(p)>.01 {
       di "`var' is statistically different white vs black at .05 - 1 star"
       }
       if e(p)<.01 & e(p)>.001 {
       di "`var' is statistically different white vs black at .01 - 2 stars"
       }
       if e(p)<.001 {
       di "`var' is statistically different white vs black at .001 - 3 stars"
       }
       }

********************************************************	   
//Figure 2. first birth by age among black/white sample
tab age firstbirth if samp_bw==1
tab age firstbirth if samp_bw==1 & racecat==1
tab age firstbirth if samp_bw==1 & racecat==2

********************************************************
//Table 4. Discrete-time logistic regression event history models with random effects predicting early childbearing (before age 22), with moderation by racialized group
//additive regressions among black/white sample only
svy, subpop(samp_bw): melogit firstbirth c.institutional_sexism i.blackwhite $controls_norace c.age#c.age || psuscid:
		outreg2 using table4, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("Institutional") replace
		
svy, subpop(samp_bw): melogit firstbirth c.interaction_sexism_unwt i.blackwhite $controls_norace c.age#c.age || psuscid:
		outreg2 using table4, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("Interactional") append			

//Moderation by race
//institutional*black	
svy, subpop(samp_bw): melogit firstbirth c.institutional_sexism##i.blackwhite $controls_norace c.age#c.age || psuscid:
		outreg2 using table4, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("Institutional interaction") append
		
//is the slope for institutional sexism statistically significant for black respondents?
//change reference group
svy, subpop(samp_bw): melogit firstbirth c.institutional_sexism##i.whiteblack $controls_norace c.age#c.age || psuscid:
		
//interactional*black		
svy, subpop(samp_bw): melogit firstbirth c.interaction_sexism_unwt##i.blackwhite $controls_norace c.age#c.age || psuscid:
		outreg2 using table4, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("Interactional interaction") append	

//even though coefficient on interaction term is not statistically significant, that does not mean that there is no variation by race in the predicted probabilities
//See Mize 2019 article for explanation of this
//Therefore, I will evaluate whether there are statistically sig differences between white/black across range of interactional sexism	
margins, dydx(blackwhite) at (interaction_sexism_unwt=(-2(1)2)) 		
marginsplot, recastci(rarea) ciopts(col(gs14)) yline(0)
//institutional sexism not moderated by race

//including both sexism measures and institutional*black		
//not including interaction*black because it is not statistically sig
svy, subpop(samp_bw): melogit firstbirth c.institutional_sexism##i.blackwhite c.interaction_sexism_unwt $controls_norace c.age#c.age || psuscid:
		outreg2 using table4, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("both interactions") append			
est store racemod	

********************************************************
//Figure 5. plot predicted probability of early childbearing by levels of institutional sexism by race
//First test racial group differences at each institutional sexism level 
//Code from Trenton Mize's 2019 article
//https://www.trentonmize.com/research/mize_2019_SocSci
//code for Mize's Figure 14 is in file: Nonlinear_Interactions--Ex_03-Nominal_X_Continuous.do
est restore racemod
margins, at(institutional_sexism=(-2(0.5)2)) over(blackwhite) post
marginsplot, xdimension(institutional_sexism) recastci(rarea) ciopts(col(gs14))

graph save "Graph" "$log\blackwhite_marginsplot.gph", replace

mlincom, clear
qui mlincom 2 - 1, stat(est se p) add rowname("Institutional: -2")
qui mlincom 4 - 3, stat(est se p) add rowname("Institutional: -1.5")
qui mlincom 6 - 5, stat(est se p) add rowname("Institutional: -1.0")
qui mlincom 8 - 7, stat(est se p) add rowname("Institutional: -0.5")
qui mlincom 10 - 9, stat(est se p) add rowname("Institutional: 0.0")
qui mlincom 12 - 11, stat(est se p) add rowname("Institutional: +0.5")
qui mlincom 14 - 13, stat(est se p) add rowname("Institutional: +1.0")
qui mlincom 16 - 15, stat(est se p) add rowname("Institutional: +1.5")
qui mlincom 18 - 17, stat(est se p) add rowname("Institutional: +2.0")
mlincom, stat(est se p) title("Racial Gap Across Range of Institutional Sexism")
//interpretation: differences between Black and White respondents become statistically significant when institutional sexism>=0 (average)
//not sig when below average (<0)

est restore racemod
* -- NOTE: Need to use mgen for this type of graph to overlay multiple lines
*Pr. Probs. for White
mgen if blackwhite == 0,	at(institutional_sexism=(-2(.5)2)) stub(White) replace
*Pr. Probs. for Black
mgen if blackwhite == 1,	at(institutional_sexism=(-2(.5)2)) stub(Black) replace

lab var 	Blackmargin1 "Black"		// Add labels for graph legend
lab var		Whitemargin1 "White"

*Create variable for significance information of group differences
gen 		BlackSig = Blackmargin1
gen 		WhiteSig = Whitemargin1
lab var 	BlackSig "Black"
lab var		WhiteSig "White"
*Replace value as missing if group difference is not sig at p<0.05
replace		WhiteSig = . if Blackinstitutional_sexism <0  
replace		BlackSig = . if Blackinstitutional_sexism <0 

*NOTE: Showing group differences with a solid line when they are 
*	sig different and a dashed line when not sig. different
twoway  (rarea Blackll1 Blackul1 Blackinstitutional_sexism, col(gs14)) ///
		(rarea Whitell1 Whiteul1 Whiteinstitutional_sexism, col(gs14)) ///
		(connected Whitemargin1 Blackinstitutional_sexism, ///
			lpat(dash) lcol(eltblue) lwid(medthick) msym(none)) ///
        (connected WhiteSig Blackinstitutional_sexism, ///
			lpat(solid) lcol(eltblue) lwid(medthick) msym(none)) ///
		(connected Blackmargin1 Blackinstitutional_sexism, ///
			lpat(dash) lcol(red*1.2) lwid(medthick) msym(none)) ///
        (connected BlackSig Blackinstitutional_sexism, ///
			lpat(solid) lcol(red*1.2) lwid(medthick) msym(none)), ///
		xtitle("Institutional Sexism") ytitle("Pr(Early Childbearing)") ///
		xlab(-2(0.5)2) ylab(0(0.05)0.15) legend(order(4 6)) ///
note("NOTE: Racial group difference (Black vs White) is significant ({it:p} < 0.05) when lines are solid", span) 
		
graph save "Graph" "$log\Fig5.gph", replace

*Explanation of graph code:
*	This first plots the confidence intervals (rarea)
*	Next, a dashed line (1st & 3rd "connected") and then overlays 
*	a solid line for places where the groups differences are 
*	significant (2nd & 4th "connected").
*	"legend" option suppresses the repeated labels for each line. 

********************************************************
//exploratory "simulation": if black respondents were exposed to same level of interactional sexism as white respondents, how many would have early first birth?
//by avg interactional sexism for white (-0.18), black (0.59)
margins, at(blackwhite=(1 0) age=(15(1)21) interaction_sexism_unwt=(-0.18 0.59)) atmeans predict(mu fixed)
********************************************************		

///////////////////////////////////////////
//ROBUSTNESS CHECKS				
///////////////////////////////////////////

********************************************************
//Appendix Table 3. region and state by year fixed effects
global controls_yr c.age /// 
		c.perfemale i.w1cpovquint c.countyblack c.countyhispanic /// 
		i.racecat1 i.borninus i.w1famst i.paredu1
		
global controls_noraceyr c.age /// 
		c.perfemale i.w1cpovquint c.countyblack c.countyhispanic /// 
		i.borninus i.w1famst i.paredu1

	
svy, subpop(sample): melogit firstbirth c.institutional_sexism c.interaction_sexism_unwt $controls_yr c.age#c.age i.region#i.year || psuscid:
	outreg2 using atable3, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("Full Sample RegionYrFE") replace	
test institutional_sexism interaction_sexism_unwt	

svy, subpop(sample): melogit firstbirth c.institutional_sexism c.interaction_sexism_unwt $controls_yr c.age#c.age i.w1state#i.year || psuscid:
	outreg2 using atable3, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("Full Sample StateYrFE") append	
test institutional_sexism interaction_sexism_unwt	

svy, subpop(samp_bw): melogit firstbirth c.institutional_sexism##i.blackwhite c.interaction_sexism_unwt $controls_noraceyr c.age#c.age i.region#i.year || psuscid:
		outreg2 using atable3, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("BW Sample RegionYrFE") append			
		
svy, subpop(samp_bw): melogit firstbirth c.institutional_sexism##i.blackwhite c.interaction_sexism_unwt $controls_noraceyr c.age#c.age i.w1state#i.year || psuscid:
		outreg2 using atable3, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("BW Sample StateYrFE") append			
				
********************************************************		
//Leave-one-out robustness check
********************************************************
//Appendix Table 4. institutional leave-one-out
egen no_lfp=rsum(zccu92a28 zccm90a15 zw1limabortfund zw1informconsent zw1parconsent zw1noabprov) if sample==1
egen no_vote=rsum(zcacw1mflabor zccm90a15 zw1limabortfund zw1informconsent zw1parconsent zw1noabprov) if sample==1
egen no_relig=rsum(zcacw1mflabor zccu92a28  zw1limabortfund zw1informconsent zw1parconsent zw1noabprov) if sample==1
egen no_limabort=rsum(zcacw1mflabor zccu92a28 zccm90a15 zw1informconsent zw1parconsent zw1noabprov) if sample==1
egen no_infcons=rsum(zcacw1mflabor zccu92a28 zccm90a15 zw1limabortfund zw1parconsent zw1noabprov) if sample==1
egen no_parcons=rsum(zcacw1mflabor zccu92a28 zccm90a15 zw1limabortfund zw1informconsent zw1noabprov) if sample==1
egen no_abprov=rsum(zcacw1mflabor zccu92a28 zccm90a15 zw1limabortfund zw1informconsent zw1parconsent) if sample==1

global leaveoneout_inst no_lfp no_vote no_relig no_limabort no_infcons no_parcons no_abprov 

foreach var in $leaveoneout_inst {
	sum `var'
	replace `var'=`var'/`r(sd)'
}

local append "replace"
foreach var in institutional_sexism $leaveoneout_inst {
	svy, subpop(sample): melogit firstbirth `var' $controls c.age#c.age || psuscid:
		outreg2 using atable4, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("`var'") `append'
		local append "append"
}


********************************************************
//Appendix Table 5. Interactional leave-one-out
egen no_hrwage=rsum(zsfmunwt_housework zsmfunwt_sexposnorms zsmfunwt_idealrel_sex zsmfunwt_momapprovesex zavgr1mfage zavgscripture) if sample==1
egen no_housework=rsum(zsmfunwt_hrwage_school zsmfunwt_sexposnorms zsmfunwt_idealrel_sex zsmfunwt_momapprovesex zavgr1mfage zavgscripture) if sample==1
egen no_sexposnorms=rsum(zsmfunwt_hrwage_school zsfmunwt_housework zsmfunwt_idealrel_sex zsmfunwt_momapprovesex zavgr1mfage zavgscripture) if sample==1
egen no_idealrelsex=rsum(zsmfunwt_hrwage_school zsfmunwt_housework zsmfunwt_sexposnorms zsmfunwt_momapprovesex zavgr1mfage zavgscripture) if sample==1
egen no_momapprovesex=rsum(zsmfunwt_hrwage_school zsfmunwt_housework zsmfunwt_sexposnorms zsmfunwt_idealrel_sex zavgr1mfage zavgscripture) if sample==1
egen no_r1mfage=rsum(zsmfunwt_hrwage_school zsfmunwt_housework zsmfunwt_sexposnorms zsmfunwt_idealrel_sex zsmfunwt_momapprovesex zavgscripture) if sample==1
egen no_scripture=rsum(zsmfunwt_hrwage_school zsfmunwt_housework zsmfunwt_sexposnorms zsmfunwt_idealrel_sex zsmfunwt_momapprovesex zavgr1mfage) if sample==1

global leaveoneout_inter no_sexposnorms no_idealrelsex no_momapprovesex no_housework no_hrwage no_r1mfage no_scripture

foreach var in $leaveoneout_inter {
	sum `var'
	replace `var'=`var'/`r(sd)'
}

local append "replace"
foreach var in interaction_sexism_unwt $leaveoneout_inter {
	svy, subpop(sample): melogit firstbirth `var' $controls c.age#c.age || psuscid:
		outreg2 using atable5, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) addstat(Subpop obs, e(N_sub)) cttop("`var'") `append'
		local append "append"
}

********************************************************		
//Disaggregate standardized sexism items and run separately
********************************************************
//Appendix Table 6. institutional measures
global institution_std zcacw1mflabor zccu92a28 zccm90a15 zw1limabortfund zw1informconsent zw1parconsent zw1noabprov

local append "replace"
foreach var in c.institutional_sexism $institution_std {
	svy, subpop(sample): melogit firstbirth `var' $controls c.age#c.age || psuscid:
	outreg2 using atable6, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) `append'
	local append "append"
}

********************************************************
//Appendix Table 7. interaction measures
global interaction_std zsmfunwt_sexposnorms zsmfunwt_idealrel_sex zsmfunwt_momapprovesex zsfmunwt_housework zsmfunwt_hrwage_school zavgr1mfage zavgscripture 


local append "replace"
foreach var in interaction_sexism_unwt $interaction_std {
	svy, subpop(sample): melogit firstbirth `var' $controls c.age#c.age || psuscid:
	outreg2 using atable7, dec(3) alpha(0.001, 0.01, 0.05, 0.10) symbol(***, **, *, †) `append'
	local append "append"
}

********************************************************
//Tables
//seeout using table2
//seeout using table4

//Figures
//Fig4
//Fig5

//Appendix
//seeout using atable2
//seeout using atable3
//seeout using atable4
//seeout using atable5
//seeout using atable6
//seeout using atable7
	
save "$data/jhs_sexism_analysis_long_final", replace
